﻿using Announcements.Contracts;
using Announcements.Database.Models;
using Announcements.Models;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace Announcements
{
    public partial class AnnouncementReadForm : Form
    {
        IBlockingLogic blockingLogic;
        IAnnouncementLogic announcementLogic;
        ICategoryLogic categoryLogic;
        IUserLogic userLogic;
        IAnnouncement Id;
        IReviewLogic reviewLogic;
        

        public AnnouncementReadForm(IBlockingLogic blockingLogic, IAnnouncementLogic announcementLogic, ICategoryLogic categoryLogic, IAnnouncement id, IReviewLogic reviewLogic)
        {
            this.blockingLogic = blockingLogic;
            this.announcementLogic = announcementLogic;
            this.categoryLogic = categoryLogic;
            this.reviewLogic = reviewLogic;
            InitializeComponent();
            Id = id;
        }

        public AnnouncementReadForm(IBlockingLogic blockingLogic, IAnnouncementLogic announcementLogic, ICategoryLogic categoryLogic, IUserLogic userLogic, IAnnouncement id)
        {
            this.blockingLogic = blockingLogic;
            this.announcementLogic = announcementLogic;
            this.categoryLogic = categoryLogic;
            this.userLogic = userLogic;
            Id = id;
        }

        private void AnnouncementReadForm_Load(object sender, EventArgs e)
        {
            Update();
        }

        private void button1_Click(object sender, EventArgs e)
        {
            var res = announcementLogic.UpdateAnnouncement(new Announcement
            {
                id = Id.id,
                text = Id.text,
                createDate = Id.createDate,
                changeDate = DateTime.Now,
                complaints = Id.complaints + 1,
                isClose = Id.isClose,
                categoryId = Id.categoryId,
                authorId = Id.authorId,
                blockingId = Id.blockingId
            });
            if (res != null)
                MessageBox.Show("Произошла ошибка");
            else
            { var resUser = userLogic.UpdateUser(new User()
            {
                id = Id.authorId.id,
                name = Id.authorId.name,
                surname = Id.authorId.surname,
                patronymic = Id.authorId.patronymic,
                email = Id.authorId.email,
                password = Id.authorId.password,
                registrDate = Id.authorId.registrDate,
                rating = (float)(Id.authorId.rating - (0.5)),
                isAdmin = Id.authorId.isAdmin,
            });
                if (!resUser)
                    MessageBox.Show("Произошла ошибка");
                else MessageBox.Show("Успешно");
             }
            Update();
        }

        private void button2_Click(object sender, EventArgs e)
        {
            var res = announcementLogic.UpdateAnnouncement(new Announcement
            {
                id = Id.id,
                text = textBox1.Text,
                createDate = Id.createDate,
                changeDate = DateTime.Now,
                complaints = Id.complaints,
                isClose = Id.isClose,
                categoryId = Id.categoryId,
                authorId = Id.authorId,
                blockingId = Id.blockingId
            });
            if (!res)
                MessageBox.Show("Произошла ошибка");
            Update();
        }

        private void button3_Click(object sender, EventArgs e)
        {
            var block = blockingLogic.ReadList().Where(b => b.name == comboBox1.Text).First();
            if (block != null)
            {
                var res = announcementLogic.UpdateAnnouncement(new Announcement
                {
                    id = Id.id,
                    text = Id.text,
                    createDate = Id.createDate,
                    changeDate = DateTime.Now,
                    complaints = Id.complaints + 1,
                    isClose = Id.isClose,
                    categoryId = Id.categoryId,
                    authorId = Id.authorId,
                    blockingId = block
                });
                if (!res)
                    MessageBox.Show("Произошла ошибка");
                Update();
            }
        }

        private void button4_Click(object sender, EventArgs e)
        {
            var res = announcementLogic.UpdateAnnouncement(new Announcement
            {
                id = Id.id,
                text = Id.text,
                createDate = Id.createDate,
                changeDate = DateTime.Now,
                complaints = Id.complaints + 1,
                isClose = true,
                categoryId = Id.categoryId,
                authorId = Id.authorId,
                blockingId = Id.blockingId
            });
            if (!res)
                MessageBox.Show("Произошла ошибка");
            Update();
        }
        public void Update()
        {
            Id = announcementLogic.ReadElement(Id.id);
            textBox2.Text = String.Empty;
            textBox1.ReadOnly = true;
            textBox1.Text = Id.text;
            label3.Text = Id.categoryId.name;
            label4.Text = Id.authorId.name + " " + Id.authorId.surname;
            label5.Text = Id.authorId.email;
            button2.Visible = false;
            label6.Visible = false;
            comboBox1.Visible = false;
            button3.Visible = false;
            button1.Visible = true;
            label7.Text = "Дата обновления: " + (Id.changeDate < Id.createDate ? Id.createDate.Date : Id.changeDate.Date);
            if (Id.isClose)
            {
                label3.Visible = true;
                label3.Text = "Объявление закрыто";
            }
            if (Id.authorId.isAdmin)
            {
                label6.Visible = true;
                label6.Text = "Заблокировать";
                comboBox1.DataSource = blockingLogic.ReadList().Select(b => b.name).ToList();
                comboBox1.Visible = true;
                button3.Visible = true;
            }

            if (MainForm.user.id == Id.authorId.id)
            {
                textBox1.ReadOnly = false;
                button2.Visible = true;
                button1.Visible = false;
            }
            if (Id.blockingId != null && Id.blockingId.name != "null")
            {
                MessageBox.Show($"Объявление было заблокировано по причине: {Id.blockingId.name}");
            }
            var rew = reviewLogic.ReadList().Where(r => r.announcementId.id == Id.id).ToList();
            foreach(var r in rew)
            {
                textBox2.Text += $"{r.createDate}: {r.authorId.name} {r.authorId.surname}: {r.text}" + Environment.NewLine; ;
            }
        }

        private void textBox1_TextChanged(object sender, EventArgs e)
        {

        }

        private void button5_Click(object sender, EventArgs e)
        {
            var res = reviewLogic.CreateReview(new Review
            {
                id = reviewLogic.ReadList().Count() + 1,
                text = textBox3.Text,
                createDate = DateTime.Now,
                complaints = 0,
                announcementId = Id,
                authorId = MainForm.user,
                blockingId = blockingLogic.ReadList().Where(r => r.name == "null").First()
            });
            Update();
        }
    }
}
