using Announcements.Contracts;
using Announcements.Database.Implements;
using Microsoft.Extensions.DependencyInjection;

namespace Announcements
{
    internal static class Program
    {
        /// <summary>
        ///  The main entry point for the application.
        /// </summary>
        [STAThread]
        static void Main()
        {
            IUserLogic userLogic = new UserLogic();
            ICategoryLogic categoryLogic = new CategoryLogic();
            IBlockingLogic blockingLogic = new BlockingLogic();
            IAnnouncementLogic announcementLogic = new AnnouncementLogic(categoryLogic, userLogic, blockingLogic);
            // To customize application configuration such as set high DPI settings or default font,
            // see https://aka.ms/applicationconfiguration.
            ApplicationConfiguration.Initialize();
            Application.Run(new AuthForm(userLogic, announcementLogic));
        }
        private static void ConfigureServices(ServiceCollection services)
        {
            services.AddTransient<IUserLogic, UserLogic>();
            services.AddTransient<ICategoryLogic, CategoryLogic>();
            services.AddTransient<IBlockingLogic, BlockingLogic>();
            services.AddTransient<IAnnouncementLogic, AnnouncementLogic>();
            services.AddTransient<IReviewLogic, ReviewLogic>();
        }
    }
}